Install the repository for several Oracle Fusion products.

## Creating a repository

Using this defined class, you can create repositories for several Oracle products. Here are some examples.

Here is an example on how to use it:

### SOA suite repository

```puppet
ora_install::rcu{'install_SOA_v11.1.1.9.0':
  rcu_file                  => 'V75907-01.zip',
  product                   => 'soasuite',
  version                   => '11.1.1.9.0',
  oracle_home               => '/u01/app/oracle/product/11.2.0.4/db_home1',
  user                      => 'oracle',
  group                     => 'dba',
  download_dir              => '/install',
  action                    => 'create',
  db_server                 => 'asm112.example.com:1521',
  db_service                => 'DB112.domain.local',
  sys_password              => 'Welcome01',
  schema_prefix             => 'DEV',
  repos_password            => 'Welcome02',
  puppet_download_mnt_point => 'puppet:///modules/software',
}
```

### webcenter repository

```puppet
ora_install::rcu{'install_WebCenter_11.1.1.7':
  rcu_file                  => 'ofm_rcu_linux_11.1.1.7.0_32_disk1_1of1.zip',
  product                   => 'webcenter',
  version                   => '11.1.1.7',
  oracle_home               => '/u01/app/oracle/product/11.2.0.4/db_home1',
  user                      => 'oracle',
  group                     => 'dba',
  download_dir              => '/install',
  action                    => 'create',
  db_server                 => 'asm112.example.com:1521',
  db_service                => 'DB112.domain.local',
  sys_password              => 'Welcome01',
  schema_prefix             => 'DEV',
  temp_tablespace           => 'TEMP',
  repos_password            => 'Welcome02',
  puppet_download_mnt_point => 'puppet:///modules/software',
}
```

### OIM, OAM repository

OIM needs an Oracle Enterprise Edition database

```puppet
ora_install::rcu{'install_OIM_11.1.2.1':
  rcu_file                  => 'V37476-01.zip',
  product                   => 'oim',
  version                   => '11.1.2.1',
  oracle_home               => '/u01/app/oracle/product/11.2.0.4/db_home1',
  user                      => 'oracle',
  group                     => 'dba',
  download_dir              => '/data/install',
  action                    => 'create',
  db_server                 => 'asm112.example.com:1521',
  db_service                => 'DB112.domain.local',
  sys_password              => 'Welcome01',
  schema_prefix             => 'DEV',
  repos_password            => 'Welcome02',
  puppet_download_mnt_point => 'puppet:///modules/software',
  logoutput                 => true,
 }
```

## deleting a repository

You can also use this defined type to delete a repository. To do so, you need te specify `delete` as action.

Here is an example:

```puppet
ora_install::rcu{'delete_SOA_11.1.1.6':
  rcu_file          => 'ofm_rcu_linux_11.1.1.6.0_disk1_1of1.zip',
  product           => 'soasuite',
  version           => '11.1.1.6',
  oracle_home       => '/oracle/product/11.2/db',
  user              => 'oracle',
  group             => 'dba',
  download_dir      => '/install',
  action            => 'delete',
  db_server         => 'asm112.example.com:1521',
  db_service        => 'DB112.domain.local',
  sys_password      => 'Welcome01',
  schema_prefix     => 'DEV',
  repos_password    => 'Welcome02',
}
```

<%- include_attributes [
  :action,
  :db_server,
  :db_service,
  :download_dir,
  :group,
  :logoutput,
  :oracle_home,
  :product,
  :puppet_download_mnt_point,
  :rcu_file,
  :remote_file,
  :repos_password,
  :schema_prefix,
  :sys_password,
  :sys_user,
  :temp_tablespace,
  :user,
  :version
]%>
