#
# See the file "LICENSE" for the full license governing this code.
#
#
# This function checks if the specfied patches are installed.
# The patch list is an array and has the syntax
#
#    ['/oracle/home/dir:patchid']
#
# It will check all registered Oracle homes for the installed patches.
#
Puppet::Functions.create_function(:'ora_patches_installed') do
  dispatch :check_patch_list do
    param 'Array', :patch_list
    return_type 'Boolean'
  end

  def check_patch_list(patch_list)
    log("patch list: #{patch_list}")
    scope = closure_scope
    oracle_homes = scope['ora_install_homes'] || []
    oracle_homes.each do |key, value|
      if value['opatch_version'] == 'Invalid'
        fail "Either ORACLE_HOME '#{key}' or '#{key}/OPatch/opatch' not found. Faulty oraInventory entry? Please fix!"
      end
    end
    log("existing homes: #{oracle_homes}")
    installed_patches = oracle_homes.nil? ? [] : oracle_homes.collect { |key, val| val['installed_patches'].map { |patch| "#{key}:#{patch}" } }.flatten
    log("installed patches: #{installed_patches}")
    patch_list.all? { |patch| installed_patches.include?(patch) }
  end

  def log(msg)
    Puppet::Util::Log.create(
      :level   => :debug,
      :message => msg,
      :source  => 'ora_patches_installed'
    )
  end
end
