#
# See the file "LICENSE" for the full license governing this code.
#
#
# This function parses a Hash of patches and looks for resources with
# sub_patches. If they are there, this function will translate it to the 
# actual list of patches that need to be on the system.
#
Puppet::Functions.create_function(:'ora_physical_patches') do
  dispatch :physical_patches do
    param 'Hash', :patch_list
    return_type 'Array'
  end

  def physical_patches(patch_list)
    return [] if patch_list.nil?
    patch_list.keys.collect do |full_patch_id|
      oracle_home, _patch_id = full_patch_id.split(':')
      sub_patches = patch_list[full_patch_id]['sub_patches']
      if sub_patches
        sub_patches.collect { |p| "#{oracle_home}:#{p}" }
      else
        full_patch_id
      end
    end.flatten
  end
end
