#
# See the file "LICENSE" for the full license governing this code.
#
require 'easy_type'
require 'puppet_x/enterprisemodules/ora_install/get_homes'
require 'puppet_x/enterprisemodules/ora_install/commands'

Puppet::Type.type(:ora_opatch).provide(:base) do
  include EasyType::Provider
  extend ::PuppetX::EnterpriseModules::OraInstall::GetHomes
  include PuppetX::EnterpriseModules::OraInstall::Commands

  mk_resource_methods

  def os_user
    @os_user ||= self.class.user_for_file(oracle_product_home_dir)
  end

  desc 'Base provider for Oracle patches'

  mk_resource_methods

  confine :true => false # This is NEVER a valid provider. It is just used as a base class

  def self.prefetch(resources)
    orainst_dir = check_single_orainst_dir(resources)
    all_patches = oracle_homes(resources).collect { |h| patches_in_home(h, orainst_dir).collect { |p| p[:name] } }.flatten
    resources.keys.each do |patch_name|
      if all_patches.include?(patch_name)
        resources[patch_name].provider = new(:name => name, :ensure => :present)
      end
    end
  end

  [:patch_id, :oracle_product_home_dir, :orainst_dir, :source, :tmp_dir].each do |prop|
    define_method(prop) do
      resource[prop]
    end
  end

  private

  def self.check_single_orainst_dir(resources)
    orainst_dir = resources.map { |k, v| v.orainst_dir }.uniq
    raise "ora_opatch doesn't support multiple orainst_dir" if orainst_dir.size > 1
    orainst_dir.first
  end
end
